summaryrefslogtreecommitdiff
path: root/libdocument/ev-document.h
diff options
context:
space:
mode:
Diffstat (limited to 'libdocument/ev-document.h')
-rw-r--r--libdocument/ev-document.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libdocument/ev-document.h b/libdocument/ev-document.h
index a3fe0727..d10d261a 100644
--- a/libdocument/ev-document.h
+++ b/libdocument/ev-document.h
@@ -20,8 +20,8 @@
* $Id$
*/
#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
#error "Only <evince-document.h> can be included directly."
#endif
#ifndef EV_DOCUMENT_H
@@ -242,7 +242,7 @@ static void backend_name##_class_intern_init (gpointer klass) \
} \
\
G_MODULE_EXPORT GType \
-register_evince_backend (GTypeModule *module) \
+register_atril_backend (GTypeModule *module) \
{ \
const GTypeInfo our_info = { \
sizeof (BackendName##Class), \
@@ -20,8 +20,8 @@
* $Id$
*/
-#if !defined (__EV_EVINCE_DOCUMENT_H_INSIDE__) && !defined (EVINCE_COMPILATION)
-#error "Only <evince-document.h> can be included directly."
+#if !defined (__EV_ATRIL_DOCUMENT_H_INSIDE__) && !defined (ATRIL_COMPILATION)
+#error "Only <atril-document.h> can be included directly."
#endif
#ifndef EV_DOCUMENT_H